==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=bg
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_evolution_visites' => 'Развитие на посещенията<br />@visites@ посещения',
	'icone_repartition_actuelle' => 'Покажи настоящата дистрибуция',
	'icone_repartition_visites' => 'Разпределяне на посещенията',
	'icone_statistiques_visites' => 'Статистика',
	'info_affichier_visites_articles_plus_visites' => 'Показване на посещения за <b>най-посещаваните статии от началото:</b>',
	'info_comment_lire_tableau' => 'Как да се чете тази схема',
	'info_forum_statistiques' => 'Статистика на посещенията',
	'info_popularite_2' => 'популярност на сайта:',
	'info_popularite_3' => 'популярност: @popularite@; посещения: @visites@',
	'info_popularite_5' => 'популярност:',
	'info_visites' => 'посещения:',
	'info_visites_plus_populaires' => 'Показване на посещения за <b>най-четени статии</b> и за <b>най-новите публикувани статии:</b>',
	'info_zoom' => 'увеличение',
	'item_gerer_statistiques' => 'Управление на статистиката', # MODIF

	// O
	'onglet_origine_visites' => 'Произход на посещенията',
	'onglet_repartition_debut' => 'отначало',
	'onglet_repartition_lang' => 'Разпределение по езици',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Мястото на статията според класификацията за популярност (посещаемост) е указана в полето. Популярността на статията (оценка от броя на посещенията за един ден, ако се следва текущия трафик) и записания брой на посещенията от самото начало, са показани в балона, който се появява, когато мишката се позиционира върху заглавието.',
	'texte_signification' => 'Тъмните ивици представляват натрупващи се посещения (общо за всички подрубрики), а светлите - броя на посещенията за всяка отделна рубрика.',
	'titre_evolution_visite' => 'Развитие на посещенията',
	'titre_liens_entrants' => 'Входящи препратки',
	'titre_page_statistiques' => 'Статистика по рубрики',
	'titre_page_statistiques_visites' => 'Статистика на посещенията'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_bg.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=bg
// ** ne pas modifier le fichier **

return [

	// I
	'icone_evolution_visites' => 'Развитие на посещенията<br />@visites@ посещения',
	'icone_repartition_actuelle' => 'Покажи настоящата дистрибуция',
	'icone_repartition_visites' => 'Разпределяне на посещенията',
	'icone_statistiques_visites' => 'Статистика',
	'info_affichier_visites_articles_plus_visites' => 'Показване на посещения за <b>най-посещаваните статии от началото:</b>',
	'info_comment_lire_tableau' => 'Как да се чете тази схема',
	'info_forum_statistiques' => 'Статистика на посещенията',
	'info_popularite_2' => 'популярност на сайта:',
	'info_popularite_3' => 'популярност: @popularite@; посещения: @visites@',
	'info_popularite_5' => 'популярност:',
	'info_visites' => 'посещения:',
	'info_visites_plus_populaires' => 'Показване на посещения за <b>най-четени статии</b> и за <b>най-новите публикувани статии:</b>',
	'info_zoom' => 'увеличение',
	'item_gerer_statistiques' => 'Управление на статистиката', # MODIF

	// O
	'onglet_origine_visites' => 'Произход на посещенията',
	'onglet_repartition_debut' => 'отначало',
	'onglet_repartition_lang' => 'Разпределение по езици',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Мястото на статията според класификацията за популярност (посещаемост) е указана в полето. Популярността на статията (оценка от броя на посещенията за един ден, ако се следва текущия трафик) и записания брой на посещенията от самото начало, са показани в балона, който се появява, когато мишката се позиционира върху заглавието.',
	'texte_signification' => 'Тъмните ивици представляват натрупващи се посещения (общо за всички подрубрики), а светлите - броя на посещенията за всяка отделна рубрика.',
	'titre_evolution_visite' => 'Развитие на посещенията',
	'titre_liens_entrants' => 'Входящи препратки',
	'titre_page_statistiques' => 'Статистика по рубрики',
	'titre_page_statistiques_visites' => 'Статистика на посещенията',
];
